@@ -1,4 +1,3 @@
-{-# LANGUAGE OverloadedStrings #-}
 {-|
     A WAI adapter to the HTML5 Server-Sent Events API.
 -}
@@ -8,12 +7,11 @@ module Network.Wai.EventSource (
     eventSourceAppIO
     ) where
 
-import           Blaze.ByteString.Builder (Builder)
 import           Data.Function (fix)
 import           Control.Concurrent.Chan (Chan, dupChan, readChan)
 import           Control.Monad.IO.Class (liftIO)
-import           Network.HTTP.Types (status200)
-import           Network.Wai (Application, Response, responseStream)
+import           Network.HTTP.Types (status200, hContentType)
+import           Network.Wai (Application, responseStream)
 
 import Network.Wai.EventSource.EventStream
 
@@ -30,7 +28,7 @@ eventSourceAppIO :: IO ServerEvent -> Application
 eventSourceAppIO src _ sendResponse =
     sendResponse $ responseStream
         status200
-        [("Content-Type", "text/event-stream")]
+        [(hContentType, "text/event-stream")]
         $ \sendChunk flush -> fix $ \loop -> do
             se <- src
             case eventToBuilder se of
